pub struct AgentEffect {
pub proposals: Vec<ProposedFact>,
}Expand description
The output of a suggestor’s execute() call.
An effect describes what a suggestor wants to suggest to the context. The engine collects effects from all eligible suggestors, validates them, and promotes them serially in deterministic order.
Fields
proposals: Vec<ProposedFact>New proposals to be validated by the engine.
Implementations
Sourceimpl AgentEffect
impl AgentEffect
Sourcepub fn with_proposal(proposal: ProposedFact) -> Self
pub fn with_proposal(proposal: ProposedFact) -> Self
Creates an effect with a single proposal.
Sourcepub fn with_proposals(proposals: Vec<ProposedFact>) -> Self
pub fn with_proposals(proposals: Vec<ProposedFact>) -> Self
Creates an effect with multiple proposals.
Sourcepub fn affected_keys(&self) -> Vec<ContextKey>
pub fn affected_keys(&self) -> Vec<ContextKey>
Returns the context keys affected by this effect.