pub struct UnitInterval(/* private fields */);Expand description
A finite value in the inclusive [0.0, 1.0] range.
Use this for confidence, normalized scores, prior weights, and thresholds.
Implementations
Sourceimpl UnitInterval
impl UnitInterval
Sourcepub fn new(value: f64) -> Result<Self, UnitIntervalError>
pub fn new(value: f64) -> Result<Self, UnitIntervalError>
Create a validated unit interval.
Returns an error for NaN, infinity, or values outside [0.0, 1.0].
Sourcepub fn clamped(value: f64) -> Self
pub fn clamped(value: f64) -> Self
Create a unit interval by clamping finite input.
Non-finite values become 0.0.
Sourcepub fn saturating_add(self, delta: f64) -> Self
pub fn saturating_add(self, delta: f64) -> Self
Add a delta and clamp the result back into the valid range.
Sourcepub fn to_basis_points(self) -> u16
pub fn to_basis_points(self) -> u16
Convert to basis points, rounded to the nearest basis point.